//@line 36 "/builds/slave/linux_repack/build/l10n-central/zh-TW/browser/firefox-l10n.js"

//@line 38 "/builds/slave/linux_repack/build/l10n-central/zh-TW/browser/firefox-l10n.js"

pref("general.useragent.locale", "zh-TW");
